Struct bitbox_api::pb::BtcSignInitRequest
source · pub struct BtcSignInitRequest {
pub coin: i32,
pub script_configs: Vec<BtcScriptConfigWithKeypath>,
pub version: u32,
pub num_inputs: u32,
pub num_outputs: u32,
pub locktime: u32,
pub format_unit: i32,
}Fields
coin: i32script_configs: Vec<BtcScriptConfigWithKeypath>used script configs in inputs and changes
version: u32must be 1 or 2
num_inputs: u32num_outputs: u32locktime: u32must be <500000000
format_unit: i32Implementations
sourceimpl BtcSignInitRequest
impl BtcSignInitRequest
sourcepub fn coin(&self) -> BtcCoin
pub fn coin(&self) -> BtcCoin
Returns the enum value of coin, or the default if the field is set to an invalid enum value.
sourcepub fn format_unit(&self) -> FormatUnit
pub fn format_unit(&self) -> FormatUnit
Returns the enum value of format_unit, or the default if the field is set to an invalid enum value.
sourcepub fn set_format_unit(&mut self, value: FormatUnit)
pub fn set_format_unit(&mut self, value: FormatUnit)
Sets format_unit to the provided enum value.