pub struct BtcSignOutputRequest {
pub ours: bool,
pub type: i32,
pub value: u64,
pub payload: Vec<u8>,
pub keypath: Vec<u32>,
pub script_config_index: u32,
pub payment_request_index: Option<u32>,
pub silent_payment: Option<SilentPayment>,
pub output_script_config_index: Option<u32>,
}Fields
ours: booltype: i32if ours is false
value: u6420 bytes for p2pkh, p2sh, pw2wpkh. 32 bytes for p2wsh.
payload: Vec<u8>if ours is false. Renamed from hash.
keypath: Vec<u32>if ours is true
script_config_index: u32If ours is true and output_script_config_index is absent. References a script config from
BTCSignInitRequest. This allows change output identification and allows us to identify
non-change outputs to the same account, so we can display this info to the user.
payment_request_index: Option<u32>silent_payment: Option<SilentPayment>If provided, type and payload is ignored. The generated output pkScript is returned in
BTCSignNextResponse. contains_silent_payment_outputs in the init request must be true.
output_script_config_index: Option<u32>If ours is true. If set, script_config_index is ignored. References an output script config
from BTCSignInitRequest. This enables verification that an output belongs to the same keystore,
even if it is from a different account than we spend from, allowing us to display this info to
the user.
Implementations
Sourceimpl BtcSignOutputRequest
impl BtcSignOutputRequest
Sourcepub fn type(&self) -> BtcOutputType
pub fn type(&self) -> BtcOutputType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: BtcOutputType)
pub fn set_type(&mut self, value: BtcOutputType)
Sets type to the provided enum value.
Sourcepub fn payment_request_index(&self) -> u32
pub fn payment_request_index(&self) -> u32
Returns the value of payment_request_index, or the default value if payment_request_index is unset.
Sourcepub fn output_script_config_index(&self) -> u32
pub fn output_script_config_index(&self) -> u32
Returns the value of output_script_config_index, or the default value if output_script_config_index is unset.